# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protopia/api/data/v1beta1/data_source.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protopia/api/data/v1beta1/data_source.proto',
  package='protopia.cloud.governance.v1beta1',
  syntax='proto3',
  serialized_options=b'Z<github.com/protopia-ai/cloud/pkg/api/data/v1beta1;datasource',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+protopia/api/data/v1beta1/data_source.proto\x12!protopia.cloud.governance.v1beta1\x1a google/protobuf/field_mask.proto\";\n\nDataSource\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"\x8e\x01\n\x17UpdateDataSourceRequest\x12\x42\n\x0b\x64\x61ta_source\x18\x01 \x01(\x0b\x32-.protopia.cloud.governance.v1beta1.DataSource\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"%\n\x17\x44\x65leteDataSourceRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteDataSourceResponse\"?\n\x16ListDataSourcesRequest\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\"w\n\x17ListDataSourcesResponse\x12\x43\n\x0c\x64\x61ta_sources\x18\x01 \x03(\x0b\x32-.protopia.cloud.governance.v1beta1.DataSource\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\"\n\x14GetDataSourceRequest\x12\n\n\x02id\x18\x01 \x01(\t2\x96\x05\n\x11\x44\x61taSourceService\x12p\n\x10\x43reateDatasource\x12-.protopia.cloud.governance.v1beta1.DataSource\x1a-.protopia.cloud.governance.v1beta1.DataSource\x12\x88\x01\n\x0fListDataSources\x12\x39.protopia.cloud.governance.v1beta1.ListDataSourcesRequest\x1a:.protopia.cloud.governance.v1beta1.ListDataSourcesResponse\x12w\n\rGetDataSource\x12\x37.protopia.cloud.governance.v1beta1.GetDataSourceRequest\x1a-.protopia.cloud.governance.v1beta1.DataSource\x12}\n\x10UpdateDatasource\x12:.protopia.cloud.governance.v1beta1.UpdateDataSourceRequest\x1a-.protopia.cloud.governance.v1beta1.DataSource\x12\x8b\x01\n\x10\x44\x65leteDatasource\x12:.protopia.cloud.governance.v1beta1.DeleteDataSourceRequest\x1a;.protopia.cloud.governance.v1beta1.DeleteDataSourceResponseB>Z<github.com/protopia-ai/cloud/pkg/api/data/v1beta1;datasourceb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_DATASOURCE = _descriptor.Descriptor(
  name='DataSource',
  full_name='protopia.cloud.governance.v1beta1.DataSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protopia.cloud.governance.v1beta1.DataSource.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='protopia.cloud.governance.v1beta1.DataSource.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='protopia.cloud.governance.v1beta1.DataSource.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=175,
)


_UPDATEDATASOURCEREQUEST = _descriptor.Descriptor(
  name='UpdateDataSourceRequest',
  full_name='protopia.cloud.governance.v1beta1.UpdateDataSourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_source', full_name='protopia.cloud.governance.v1beta1.UpdateDataSourceRequest.data_source', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='protopia.cloud.governance.v1beta1.UpdateDataSourceRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=178,
  serialized_end=320,
)


_DELETEDATASOURCEREQUEST = _descriptor.Descriptor(
  name='DeleteDataSourceRequest',
  full_name='protopia.cloud.governance.v1beta1.DeleteDataSourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protopia.cloud.governance.v1beta1.DeleteDataSourceRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=322,
  serialized_end=359,
)


_DELETEDATASOURCERESPONSE = _descriptor.Descriptor(
  name='DeleteDataSourceResponse',
  full_name='protopia.cloud.governance.v1beta1.DeleteDataSourceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=361,
  serialized_end=387,
)


_LISTDATASOURCESREQUEST = _descriptor.Descriptor(
  name='ListDataSourcesRequest',
  full_name='protopia.cloud.governance.v1beta1.ListDataSourcesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='page_token', full_name='protopia.cloud.governance.v1beta1.ListDataSourcesRequest.page_token', index=0,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='protopia.cloud.governance.v1beta1.ListDataSourcesRequest.page_size', index=1,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=389,
  serialized_end=452,
)


_LISTDATASOURCESRESPONSE = _descriptor.Descriptor(
  name='ListDataSourcesResponse',
  full_name='protopia.cloud.governance.v1beta1.ListDataSourcesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_sources', full_name='protopia.cloud.governance.v1beta1.ListDataSourcesResponse.data_sources', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='protopia.cloud.governance.v1beta1.ListDataSourcesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=454,
  serialized_end=573,
)


_GETDATASOURCEREQUEST = _descriptor.Descriptor(
  name='GetDataSourceRequest',
  full_name='protopia.cloud.governance.v1beta1.GetDataSourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protopia.cloud.governance.v1beta1.GetDataSourceRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=575,
  serialized_end=609,
)

_UPDATEDATASOURCEREQUEST.fields_by_name['data_source'].message_type = _DATASOURCE
_UPDATEDATASOURCEREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTDATASOURCESRESPONSE.fields_by_name['data_sources'].message_type = _DATASOURCE
DESCRIPTOR.message_types_by_name['DataSource'] = _DATASOURCE
DESCRIPTOR.message_types_by_name['UpdateDataSourceRequest'] = _UPDATEDATASOURCEREQUEST
DESCRIPTOR.message_types_by_name['DeleteDataSourceRequest'] = _DELETEDATASOURCEREQUEST
DESCRIPTOR.message_types_by_name['DeleteDataSourceResponse'] = _DELETEDATASOURCERESPONSE
DESCRIPTOR.message_types_by_name['ListDataSourcesRequest'] = _LISTDATASOURCESREQUEST
DESCRIPTOR.message_types_by_name['ListDataSourcesResponse'] = _LISTDATASOURCESRESPONSE
DESCRIPTOR.message_types_by_name['GetDataSourceRequest'] = _GETDATASOURCEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DataSource = _reflection.GeneratedProtocolMessageType('DataSource', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCE,
  '__module__' : 'protopia.api.data.v1beta1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.governance.v1beta1.DataSource)
  })
_sym_db.RegisterMessage(DataSource)

UpdateDataSourceRequest = _reflection.GeneratedProtocolMessageType('UpdateDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASOURCEREQUEST,
  '__module__' : 'protopia.api.data.v1beta1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.governance.v1beta1.UpdateDataSourceRequest)
  })
_sym_db.RegisterMessage(UpdateDataSourceRequest)

DeleteDataSourceRequest = _reflection.GeneratedProtocolMessageType('DeleteDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATASOURCEREQUEST,
  '__module__' : 'protopia.api.data.v1beta1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.governance.v1beta1.DeleteDataSourceRequest)
  })
_sym_db.RegisterMessage(DeleteDataSourceRequest)

DeleteDataSourceResponse = _reflection.GeneratedProtocolMessageType('DeleteDataSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATASOURCERESPONSE,
  '__module__' : 'protopia.api.data.v1beta1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.governance.v1beta1.DeleteDataSourceResponse)
  })
_sym_db.RegisterMessage(DeleteDataSourceResponse)

ListDataSourcesRequest = _reflection.GeneratedProtocolMessageType('ListDataSourcesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASOURCESREQUEST,
  '__module__' : 'protopia.api.data.v1beta1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.governance.v1beta1.ListDataSourcesRequest)
  })
_sym_db.RegisterMessage(ListDataSourcesRequest)

ListDataSourcesResponse = _reflection.GeneratedProtocolMessageType('ListDataSourcesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASOURCESRESPONSE,
  '__module__' : 'protopia.api.data.v1beta1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.governance.v1beta1.ListDataSourcesResponse)
  })
_sym_db.RegisterMessage(ListDataSourcesResponse)

GetDataSourceRequest = _reflection.GeneratedProtocolMessageType('GetDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASOURCEREQUEST,
  '__module__' : 'protopia.api.data.v1beta1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.governance.v1beta1.GetDataSourceRequest)
  })
_sym_db.RegisterMessage(GetDataSourceRequest)


DESCRIPTOR._options = None

_DATASOURCESERVICE = _descriptor.ServiceDescriptor(
  name='DataSourceService',
  full_name='protopia.cloud.governance.v1beta1.DataSourceService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=612,
  serialized_end=1274,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateDatasource',
    full_name='protopia.cloud.governance.v1beta1.DataSourceService.CreateDatasource',
    index=0,
    containing_service=None,
    input_type=_DATASOURCE,
    output_type=_DATASOURCE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDataSources',
    full_name='protopia.cloud.governance.v1beta1.DataSourceService.ListDataSources',
    index=1,
    containing_service=None,
    input_type=_LISTDATASOURCESREQUEST,
    output_type=_LISTDATASOURCESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDataSource',
    full_name='protopia.cloud.governance.v1beta1.DataSourceService.GetDataSource',
    index=2,
    containing_service=None,
    input_type=_GETDATASOURCEREQUEST,
    output_type=_DATASOURCE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDatasource',
    full_name='protopia.cloud.governance.v1beta1.DataSourceService.UpdateDatasource',
    index=3,
    containing_service=None,
    input_type=_UPDATEDATASOURCEREQUEST,
    output_type=_DATASOURCE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDatasource',
    full_name='protopia.cloud.governance.v1beta1.DataSourceService.DeleteDatasource',
    index=4,
    containing_service=None,
    input_type=_DELETEDATASOURCEREQUEST,
    output_type=_DELETEDATASOURCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATASOURCESERVICE)

DESCRIPTOR.services_by_name['DataSourceService'] = _DATASOURCESERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protopia/api/iam/v1beta1/iam_role.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protopia.api.iam.v1beta1 import role_pb2 as protopia_dot_api_dot_iam_dot_v1beta1_dot_role__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protopia/api/iam/v1beta1/iam_role.proto',
  package='protopia.cloud.iam.v1beta1',
  syntax='proto3',
  serialized_options=b'Z4github.com/protopia-ai/cloud/pkg/api/iam/v1beta1;iam',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'protopia/api/iam/v1beta1/iam_role.proto\x12\x1aprotopia.cloud.iam.v1beta1\x1a#protopia/api/iam/v1beta1/role.proto\"\x1c\n\x0eGetRoleRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x1f\n\x11\x44\x65leteRoleRequest\x12\n\n\x02id\x18\x01 \x01(\t\" \n\x12\x44\x65leteRoleResponse\x12\n\n\x02id\x18\x01 \x01(\t\"9\n\x10ListRolesRequest\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\"]\n\x11ListRolesResponse\x12/\n\x05roles\x18\x01 \x03(\x0b\x32 .protopia.cloud.iam.v1beta1.Role\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"9\n\x15\x41\x64\x64RoleMembersRequest\x12\x0f\n\x07role_id\x18\x01 \x01(\t\x12\x0f\n\x07members\x18\x02 \x03(\t\"\x18\n\x16\x41\x64\x64RoleMembersResponse\":\n\x17RemoveRoleMemberRequest\x12\x0f\n\x07role_id\x18\x01 \x01(\t\x12\x0e\n\x06member\x18\x02 \x01(\t\"\x1a\n\x18RemoveRoleMemberResponse2\x83\x05\n\x07IAMRole\x12P\n\nUpsertRole\x12 .protopia.cloud.iam.v1beta1.Role\x1a .protopia.cloud.iam.v1beta1.Role\x12W\n\x07GetRole\x12*.protopia.cloud.iam.v1beta1.GetRoleRequest\x1a .protopia.cloud.iam.v1beta1.Role\x12k\n\nDeleteRole\x12-.protopia.cloud.iam.v1beta1.DeleteRoleRequest\x1a..protopia.cloud.iam.v1beta1.DeleteRoleResponse\x12h\n\tListRoles\x12,.protopia.cloud.iam.v1beta1.ListRolesRequest\x1a-.protopia.cloud.iam.v1beta1.ListRolesResponse\x12w\n\x0e\x41\x64\x64RoleMembers\x12\x31.protopia.cloud.iam.v1beta1.AddRoleMembersRequest\x1a\x32.protopia.cloud.iam.v1beta1.AddRoleMembersResponse\x12}\n\x10RemoveRoleMember\x12\x33.protopia.cloud.iam.v1beta1.RemoveRoleMemberRequest\x1a\x34.protopia.cloud.iam.v1beta1.RemoveRoleMemberResponseB6Z4github.com/protopia-ai/cloud/pkg/api/iam/v1beta1;iamb\x06proto3'
  ,
  dependencies=[protopia_dot_api_dot_iam_dot_v1beta1_dot_role__pb2.DESCRIPTOR,])




_GETROLEREQUEST = _descriptor.Descriptor(
  name='GetRoleRequest',
  full_name='protopia.cloud.iam.v1beta1.GetRoleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protopia.cloud.iam.v1beta1.GetRoleRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=108,
  serialized_end=136,
)


_DELETEROLEREQUEST = _descriptor.Descriptor(
  name='DeleteRoleRequest',
  full_name='protopia.cloud.iam.v1beta1.DeleteRoleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protopia.cloud.iam.v1beta1.DeleteRoleRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=138,
  serialized_end=169,
)


_DELETEROLERESPONSE = _descriptor.Descriptor(
  name='DeleteRoleResponse',
  full_name='protopia.cloud.iam.v1beta1.DeleteRoleResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protopia.cloud.iam.v1beta1.DeleteRoleResponse.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=171,
  serialized_end=203,
)


_LISTROLESREQUEST = _descriptor.Descriptor(
  name='ListRolesRequest',
  full_name='protopia.cloud.iam.v1beta1.ListRolesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='page_token', full_name='protopia.cloud.iam.v1beta1.ListRolesRequest.page_token', index=0,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='protopia.cloud.iam.v1beta1.ListRolesRequest.page_size', index=1,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=262,
)


_LISTROLESRESPONSE = _descriptor.Descriptor(
  name='ListRolesResponse',
  full_name='protopia.cloud.iam.v1beta1.ListRolesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='roles', full_name='protopia.cloud.iam.v1beta1.ListRolesResponse.roles', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='protopia.cloud.iam.v1beta1.ListRolesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=264,
  serialized_end=357,
)


_ADDROLEMEMBERSREQUEST = _descriptor.Descriptor(
  name='AddRoleMembersRequest',
  full_name='protopia.cloud.iam.v1beta1.AddRoleMembersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='role_id', full_name='protopia.cloud.iam.v1beta1.AddRoleMembersRequest.role_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='members', full_name='protopia.cloud.iam.v1beta1.AddRoleMembersRequest.members', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=359,
  serialized_end=416,
)


_ADDROLEMEMBERSRESPONSE = _descriptor.Descriptor(
  name='AddRoleMembersResponse',
  full_name='protopia.cloud.iam.v1beta1.AddRoleMembersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=418,
  serialized_end=442,
)


_REMOVEROLEMEMBERREQUEST = _descriptor.Descriptor(
  name='RemoveRoleMemberRequest',
  full_name='protopia.cloud.iam.v1beta1.RemoveRoleMemberRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='role_id', full_name='protopia.cloud.iam.v1beta1.RemoveRoleMemberRequest.role_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='member', full_name='protopia.cloud.iam.v1beta1.RemoveRoleMemberRequest.member', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=444,
  serialized_end=502,
)


_REMOVEROLEMEMBERRESPONSE = _descriptor.Descriptor(
  name='RemoveRoleMemberResponse',
  full_name='protopia.cloud.iam.v1beta1.RemoveRoleMemberResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=504,
  serialized_end=530,
)

_LISTROLESRESPONSE.fields_by_name['roles'].message_type = protopia_dot_api_dot_iam_dot_v1beta1_dot_role__pb2._ROLE
DESCRIPTOR.message_types_by_name['GetRoleRequest'] = _GETROLEREQUEST
DESCRIPTOR.message_types_by_name['DeleteRoleRequest'] = _DELETEROLEREQUEST
DESCRIPTOR.message_types_by_name['DeleteRoleResponse'] = _DELETEROLERESPONSE
DESCRIPTOR.message_types_by_name['ListRolesRequest'] = _LISTROLESREQUEST
DESCRIPTOR.message_types_by_name['ListRolesResponse'] = _LISTROLESRESPONSE
DESCRIPTOR.message_types_by_name['AddRoleMembersRequest'] = _ADDROLEMEMBERSREQUEST
DESCRIPTOR.message_types_by_name['AddRoleMembersResponse'] = _ADDROLEMEMBERSRESPONSE
DESCRIPTOR.message_types_by_name['RemoveRoleMemberRequest'] = _REMOVEROLEMEMBERREQUEST
DESCRIPTOR.message_types_by_name['RemoveRoleMemberResponse'] = _REMOVEROLEMEMBERRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetRoleRequest = _reflection.GeneratedProtocolMessageType('GetRoleRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETROLEREQUEST,
  '__module__' : 'protopia.api.iam.v1beta1.iam_role_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.GetRoleRequest)
  })
_sym_db.RegisterMessage(GetRoleRequest)

DeleteRoleRequest = _reflection.GeneratedProtocolMessageType('DeleteRoleRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEROLEREQUEST,
  '__module__' : 'protopia.api.iam.v1beta1.iam_role_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.DeleteRoleRequest)
  })
_sym_db.RegisterMessage(DeleteRoleRequest)

DeleteRoleResponse = _reflection.GeneratedProtocolMessageType('DeleteRoleResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEROLERESPONSE,
  '__module__' : 'protopia.api.iam.v1beta1.iam_role_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.DeleteRoleResponse)
  })
_sym_db.RegisterMessage(DeleteRoleResponse)

ListRolesRequest = _reflection.GeneratedProtocolMessageType('ListRolesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTROLESREQUEST,
  '__module__' : 'protopia.api.iam.v1beta1.iam_role_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.ListRolesRequest)
  })
_sym_db.RegisterMessage(ListRolesRequest)

ListRolesResponse = _reflection.GeneratedProtocolMessageType('ListRolesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTROLESRESPONSE,
  '__module__' : 'protopia.api.iam.v1beta1.iam_role_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.ListRolesResponse)
  })
_sym_db.RegisterMessage(ListRolesResponse)

AddRoleMembersRequest = _reflection.GeneratedProtocolMessageType('AddRoleMembersRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDROLEMEMBERSREQUEST,
  '__module__' : 'protopia.api.iam.v1beta1.iam_role_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.AddRoleMembersRequest)
  })
_sym_db.RegisterMessage(AddRoleMembersRequest)

AddRoleMembersResponse = _reflection.GeneratedProtocolMessageType('AddRoleMembersResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDROLEMEMBERSRESPONSE,
  '__module__' : 'protopia.api.iam.v1beta1.iam_role_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.AddRoleMembersResponse)
  })
_sym_db.RegisterMessage(AddRoleMembersResponse)

RemoveRoleMemberRequest = _reflection.GeneratedProtocolMessageType('RemoveRoleMemberRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEROLEMEMBERREQUEST,
  '__module__' : 'protopia.api.iam.v1beta1.iam_role_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.RemoveRoleMemberRequest)
  })
_sym_db.RegisterMessage(RemoveRoleMemberRequest)

RemoveRoleMemberResponse = _reflection.GeneratedProtocolMessageType('RemoveRoleMemberResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEROLEMEMBERRESPONSE,
  '__module__' : 'protopia.api.iam.v1beta1.iam_role_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.RemoveRoleMemberResponse)
  })
_sym_db.RegisterMessage(RemoveRoleMemberResponse)


DESCRIPTOR._options = None

_IAMROLE = _descriptor.ServiceDescriptor(
  name='IAMRole',
  full_name='protopia.cloud.iam.v1beta1.IAMRole',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=533,
  serialized_end=1176,
  methods=[
  _descriptor.MethodDescriptor(
    name='UpsertRole',
    full_name='protopia.cloud.iam.v1beta1.IAMRole.UpsertRole',
    index=0,
    containing_service=None,
    input_type=protopia_dot_api_dot_iam_dot_v1beta1_dot_role__pb2._ROLE,
    output_type=protopia_dot_api_dot_iam_dot_v1beta1_dot_role__pb2._ROLE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRole',
    full_name='protopia.cloud.iam.v1beta1.IAMRole.GetRole',
    index=1,
    containing_service=None,
    input_type=_GETROLEREQUEST,
    output_type=protopia_dot_api_dot_iam_dot_v1beta1_dot_role__pb2._ROLE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteRole',
    full_name='protopia.cloud.iam.v1beta1.IAMRole.DeleteRole',
    index=2,
    containing_service=None,
    input_type=_DELETEROLEREQUEST,
    output_type=_DELETEROLERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListRoles',
    full_name='protopia.cloud.iam.v1beta1.IAMRole.ListRoles',
    index=3,
    containing_service=None,
    input_type=_LISTROLESREQUEST,
    output_type=_LISTROLESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddRoleMembers',
    full_name='protopia.cloud.iam.v1beta1.IAMRole.AddRoleMembers',
    index=4,
    containing_service=None,
    input_type=_ADDROLEMEMBERSREQUEST,
    output_type=_ADDROLEMEMBERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveRoleMember',
    full_name='protopia.cloud.iam.v1beta1.IAMRole.RemoveRoleMember',
    index=5,
    containing_service=None,
    input_type=_REMOVEROLEMEMBERREQUEST,
    output_type=_REMOVEROLEMEMBERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_IAMROLE)

DESCRIPTOR.services_by_name['IAMRole'] = _IAMROLE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from protopia.api.iam.v1beta1 import iam_policy_pb2 as protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__policy__pb2
from protopia.api.iam.v1beta1 import policy_pb2 as protopia_dot_api_dot_iam_dot_v1beta1_dot_policy__pb2


class IAMPolicyStub(object):
    """IAM policy services handles the identity and access management policy. 
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetIamPolicy = channel.unary_unary(
                '/protopia.cloud.iam.v1beta1.IAMPolicy/SetIamPolicy',
                request_serializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__policy__pb2.SetIamPolicyRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_policy__pb2.Policy.FromString,
                )
        self.GetIamPolicy = channel.unary_unary(
                '/protopia.cloud.iam.v1beta1.IAMPolicy/GetIamPolicy',
                request_serializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__policy__pb2.GetIamPolicyRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_policy__pb2.Policy.FromString,
                )
        self.ListIamPolicies = channel.unary_unary(
                '/protopia.cloud.iam.v1beta1.IAMPolicy/ListIamPolicies',
                request_serializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__policy__pb2.ListIamPoliciesRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__policy__pb2.ListIamPoliciesResponse.FromString,
                )
        self.DeleteIamPolicy = channel.unary_unary(
                '/protopia.cloud.iam.v1beta1.IAMPolicy/DeleteIamPolicy',
                request_serializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__policy__pb2.DeleteIamPolicyRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__policy__pb2.DeleteIamPolicyResponse.FromString,
                )
        self.TestIamPermissions = channel.unary_unary(
                '/protopia.cloud.iam.v1beta1.IAMPolicy/TestIamPermissions',
                request_serializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__policy__pb2.TestIamPermissionsRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__policy__pb2.TestIamPermissionsResponse.FromString,
                )


class IAMPolicyServicer(object):
    """IAM policy services handles the identity and access management policy. 
    """

    def SetIamPolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIamPolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListIamPolicies(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteIamPolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TestIamPermissions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_IAMPolicyServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetIamPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.SetIamPolicy,
                    request_deserializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__policy__pb2.SetIamPolicyRequest.FromString,
                    response_serializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_policy__pb2.Policy.SerializeToString,
            ),
            'GetIamPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIamPolicy,
                    request_deserializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__policy__pb2.GetIamPolicyRequest.FromString,
                    response_serializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_policy__pb2.Policy.SerializeToString,
            ),
            'ListIamPolicies': grpc.unary_unary_rpc_method_handler(
                    servicer.ListIamPolicies,
                    request_deserializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__policy__pb2.ListIamPoliciesRequest.FromString,
                    response_serializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__policy__pb2.ListIamPoliciesResponse.SerializeToString,
            ),
            'DeleteIamPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteIamPolicy,
                    request_deserializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__policy__pb2.DeleteIamPolicyRequest.FromString,
                    response_serializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__policy__pb2.DeleteIamPolicyResponse.SerializeToString,
            ),
            'TestIamPermissions': grpc.unary_unary_rpc_method_handler(
                    servicer.TestIamPermissions,
                    request_deserializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__policy__pb2.TestIamPermissionsRequest.FromString,
                    response_serializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__policy__pb2.TestIamPermissionsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'protopia.cloud.iam.v1beta1.IAMPolicy', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class IAMPolicy(object):
    """IAM policy services handles the identity and access management policy. 
    """

    @staticmethod
    def SetIamPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.iam.v1beta1.IAMPolicy/SetIamPolicy',
            protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__policy__pb2.SetIamPolicyRequest.SerializeToString,
            protopia_dot_api_dot_iam_dot_v1beta1_dot_policy__pb2.Policy.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIamPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.iam.v1beta1.IAMPolicy/GetIamPolicy',
            protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__policy__pb2.GetIamPolicyRequest.SerializeToString,
            protopia_dot_api_dot_iam_dot_v1beta1_dot_policy__pb2.Policy.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListIamPolicies(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.iam.v1beta1.IAMPolicy/ListIamPolicies',
            protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__policy__pb2.ListIamPoliciesRequest.SerializeToString,
            protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__policy__pb2.ListIamPoliciesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteIamPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.iam.v1beta1.IAMPolicy/DeleteIamPolicy',
            protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__policy__pb2.DeleteIamPolicyRequest.SerializeToString,
            protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__policy__pb2.DeleteIamPolicyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TestIamPermissions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.iam.v1beta1.IAMPolicy/TestIamPermissions',
            protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__policy__pb2.TestIamPermissionsRequest.SerializeToString,
            protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__policy__pb2.TestIamPermissionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protopia/api/tenant/v1beta1/organization.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protopia/api/tenant/v1beta1/organization.proto',
  package='protopia.cloud.tenant.v1beta1',
  syntax='proto3',
  serialized_options=b'Z:github.com/protopia-ai/cloud/pkg/api/tenant/v1beta1;tenant',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.protopia/api/tenant/v1beta1/organization.proto\x12\x1dprotopia.cloud.tenant.v1beta1\x1a google/protobuf/field_mask.proto\"H\n\x0cOrganization\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05owner\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\"$\n\x16GetOrganizationRequest\x12\n\n\x02id\x18\x01 \x01(\t\"A\n\x18ListOrganizationsRequest\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\"x\n\x19ListOrganizationsResponse\x12\x42\n\rorganizations\x18\x01 \x03(\x0b\x32+.protopia.cloud.tenant.v1beta1.Organization\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x8f\x01\n\x19UpdateOrganizationRequest\x12\x41\n\x0corganization\x18\x01 \x01(\x0b\x32+.protopia.cloud.tenant.v1beta1.Organization\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1c\n\x1aUpdateOrganizationResponse\"\'\n\x19\x44\x65leteOrganizationRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x1c\n\x1a\x44\x65leteOrganizationResponse\"@\n\x1d\x41\x64\x64OrganizationMembersRequest\x12\x0e\n\x06org_id\x18\x01 \x01(\t\x12\x0f\n\x07members\x18\x02 \x03(\t\" \n\x1e\x41\x64\x64OrganizationMembersResponse\"A\n\x1fRemoveOrganizationMemberRequest\x12\x0e\n\x06org_id\x18\x01 \x01(\t\x12\x0e\n\x06member\x18\x02 \x01(\t\"\"\n RemoveOrganizationMemberResponse2\xd3\x07\n\x13OrganizationService\x12n\n\x12\x43reateOrganization\x12+.protopia.cloud.tenant.v1beta1.Organization\x1a+.protopia.cloud.tenant.v1beta1.Organization\x12u\n\x0fGetOrganization\x12\x35.protopia.cloud.tenant.v1beta1.GetOrganizationRequest\x1a+.protopia.cloud.tenant.v1beta1.Organization\x12\x86\x01\n\x11ListOrganizations\x12\x37.protopia.cloud.tenant.v1beta1.ListOrganizationsRequest\x1a\x38.protopia.cloud.tenant.v1beta1.ListOrganizationsResponse\x12\x89\x01\n\x12UpdateOrganization\x12\x38.protopia.cloud.tenant.v1beta1.UpdateOrganizationRequest\x1a\x39.protopia.cloud.tenant.v1beta1.UpdateOrganizationResponse\x12\x89\x01\n\x12\x44\x65leteOrganization\x12\x38.protopia.cloud.tenant.v1beta1.DeleteOrganizationRequest\x1a\x39.protopia.cloud.tenant.v1beta1.DeleteOrganizationResponse\x12\x95\x01\n\x16\x41\x64\x64OrganizationMembers\x12<.protopia.cloud.tenant.v1beta1.AddOrganizationMembersRequest\x1a=.protopia.cloud.tenant.v1beta1.AddOrganizationMembersResponse\x12\x9b\x01\n\x18RemoveOrganizationMember\x12>.protopia.cloud.tenant.v1beta1.RemoveOrganizationMemberRequest\x1a?.protopia.cloud.tenant.v1beta1.RemoveOrganizationMemberResponseB<Z:github.com/protopia-ai/cloud/pkg/api/tenant/v1beta1;tenantb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_ORGANIZATION = _descriptor.Descriptor(
  name='Organization',
  full_name='protopia.cloud.tenant.v1beta1.Organization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protopia.cloud.tenant.v1beta1.Organization.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='protopia.cloud.tenant.v1beta1.Organization.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='protopia.cloud.tenant.v1beta1.Organization.owner', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='members', full_name='protopia.cloud.tenant.v1beta1.Organization.members', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=115,
  serialized_end=187,
)


_GETORGANIZATIONREQUEST = _descriptor.Descriptor(
  name='GetOrganizationRequest',
  full_name='protopia.cloud.tenant.v1beta1.GetOrganizationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protopia.cloud.tenant.v1beta1.GetOrganizationRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=189,
  serialized_end=225,
)


_LISTORGANIZATIONSREQUEST = _descriptor.Descriptor(
  name='ListOrganizationsRequest',
  full_name='protopia.cloud.tenant.v1beta1.ListOrganizationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='page_token', full_name='protopia.cloud.tenant.v1beta1.ListOrganizationsRequest.page_token', index=0,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='protopia.cloud.tenant.v1beta1.ListOrganizationsRequest.page_size', index=1,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=227,
  serialized_end=292,
)


_LISTORGANIZATIONSRESPONSE = _descriptor.Descriptor(
  name='ListOrganizationsResponse',
  full_name='protopia.cloud.tenant.v1beta1.ListOrganizationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='organizations', full_name='protopia.cloud.tenant.v1beta1.ListOrganizationsResponse.organizations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='protopia.cloud.tenant.v1beta1.ListOrganizationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=294,
  serialized_end=414,
)


_UPDATEORGANIZATIONREQUEST = _descriptor.Descriptor(
  name='UpdateOrganizationRequest',
  full_name='protopia.cloud.tenant.v1beta1.UpdateOrganizationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='organization', full_name='protopia.cloud.tenant.v1beta1.UpdateOrganizationRequest.organization', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='protopia.cloud.tenant.v1beta1.UpdateOrganizationRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=417,
  serialized_end=560,
)


_UPDATEORGANIZATIONRESPONSE = _descriptor.Descriptor(
  name='UpdateOrganizationResponse',
  full_name='protopia.cloud.tenant.v1beta1.UpdateOrganizationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=562,
  serialized_end=590,
)


_DELETEORGANIZATIONREQUEST = _descriptor.Descriptor(
  name='DeleteOrganizationRequest',
  full_name='protopia.cloud.tenant.v1beta1.DeleteOrganizationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protopia.cloud.tenant.v1beta1.DeleteOrganizationRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=592,
  serialized_end=631,
)


_DELETEORGANIZATIONRESPONSE = _descriptor.Descriptor(
  name='DeleteOrganizationResponse',
  full_name='protopia.cloud.tenant.v1beta1.DeleteOrganizationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=633,
  serialized_end=661,
)


_ADDORGANIZATIONMEMBERSREQUEST = _descriptor.Descriptor(
  name='AddOrganizationMembersRequest',
  full_name='protopia.cloud.tenant.v1beta1.AddOrganizationMembersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='org_id', full_name='protopia.cloud.tenant.v1beta1.AddOrganizationMembersRequest.org_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='members', full_name='protopia.cloud.tenant.v1beta1.AddOrganizationMembersRequest.members', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=663,
  serialized_end=727,
)


_ADDORGANIZATIONMEMBERSRESPONSE = _descriptor.Descriptor(
  name='AddOrganizationMembersResponse',
  full_name='protopia.cloud.tenant.v1beta1.AddOrganizationMembersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=729,
  serialized_end=761,
)


_REMOVEORGANIZATIONMEMBERREQUEST = _descriptor.Descriptor(
  name='RemoveOrganizationMemberRequest',
  full_name='protopia.cloud.tenant.v1beta1.RemoveOrganizationMemberRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='org_id', full_name='protopia.cloud.tenant.v1beta1.RemoveOrganizationMemberRequest.org_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='member', full_name='protopia.cloud.tenant.v1beta1.RemoveOrganizationMemberRequest.member', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=763,
  serialized_end=828,
)


_REMOVEORGANIZATIONMEMBERRESPONSE = _descriptor.Descriptor(
  name='RemoveOrganizationMemberResponse',
  full_name='protopia.cloud.tenant.v1beta1.RemoveOrganizationMemberResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=830,
  serialized_end=864,
)

_LISTORGANIZATIONSRESPONSE.fields_by_name['organizations'].message_type = _ORGANIZATION
_UPDATEORGANIZATIONREQUEST.fields_by_name['organization'].message_type = _ORGANIZATION
_UPDATEORGANIZATIONREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
DESCRIPTOR.message_types_by_name['Organization'] = _ORGANIZATION
DESCRIPTOR.message_types_by_name['GetOrganizationRequest'] = _GETORGANIZATIONREQUEST
DESCRIPTOR.message_types_by_name['ListOrganizationsRequest'] = _LISTORGANIZATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListOrganizationsResponse'] = _LISTORGANIZATIONSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateOrganizationRequest'] = _UPDATEORGANIZATIONREQUEST
DESCRIPTOR.message_types_by_name['UpdateOrganizationResponse'] = _UPDATEORGANIZATIONRESPONSE
DESCRIPTOR.message_types_by_name['DeleteOrganizationRequest'] = _DELETEORGANIZATIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteOrganizationResponse'] = _DELETEORGANIZATIONRESPONSE
DESCRIPTOR.message_types_by_name['AddOrganizationMembersRequest'] = _ADDORGANIZATIONMEMBERSREQUEST
DESCRIPTOR.message_types_by_name['AddOrganizationMembersResponse'] = _ADDORGANIZATIONMEMBERSRESPONSE
DESCRIPTOR.message_types_by_name['RemoveOrganizationMemberRequest'] = _REMOVEORGANIZATIONMEMBERREQUEST
DESCRIPTOR.message_types_by_name['RemoveOrganizationMemberResponse'] = _REMOVEORGANIZATIONMEMBERRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Organization = _reflection.GeneratedProtocolMessageType('Organization', (_message.Message,), {
  'DESCRIPTOR' : _ORGANIZATION,
  '__module__' : 'protopia.api.tenant.v1beta1.organization_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.tenant.v1beta1.Organization)
  })
_sym_db.RegisterMessage(Organization)

GetOrganizationRequest = _reflection.GeneratedProtocolMessageType('GetOrganizationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETORGANIZATIONREQUEST,
  '__module__' : 'protopia.api.tenant.v1beta1.organization_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.tenant.v1beta1.GetOrganizationRequest)
  })
_sym_db.RegisterMessage(GetOrganizationRequest)

ListOrganizationsRequest = _reflection.GeneratedProtocolMessageType('ListOrganizationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTORGANIZATIONSREQUEST,
  '__module__' : 'protopia.api.tenant.v1beta1.organization_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.tenant.v1beta1.ListOrganizationsRequest)
  })
_sym_db.RegisterMessage(ListOrganizationsRequest)

ListOrganizationsResponse = _reflection.GeneratedProtocolMessageType('ListOrganizationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTORGANIZATIONSRESPONSE,
  '__module__' : 'protopia.api.tenant.v1beta1.organization_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.tenant.v1beta1.ListOrganizationsResponse)
  })
_sym_db.RegisterMessage(ListOrganizationsResponse)

UpdateOrganizationRequest = _reflection.GeneratedProtocolMessageType('UpdateOrganizationRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEORGANIZATIONREQUEST,
  '__module__' : 'protopia.api.tenant.v1beta1.organization_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.tenant.v1beta1.UpdateOrganizationRequest)
  })
_sym_db.RegisterMessage(UpdateOrganizationRequest)

UpdateOrganizationResponse = _reflection.GeneratedProtocolMessageType('UpdateOrganizationResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEORGANIZATIONRESPONSE,
  '__module__' : 'protopia.api.tenant.v1beta1.organization_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.tenant.v1beta1.UpdateOrganizationResponse)
  })
_sym_db.RegisterMessage(UpdateOrganizationResponse)

DeleteOrganizationRequest = _reflection.GeneratedProtocolMessageType('DeleteOrganizationRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEORGANIZATIONREQUEST,
  '__module__' : 'protopia.api.tenant.v1beta1.organization_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.tenant.v1beta1.DeleteOrganizationRequest)
  })
_sym_db.RegisterMessage(DeleteOrganizationRequest)

DeleteOrganizationResponse = _reflection.GeneratedProtocolMessageType('DeleteOrganizationResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEORGANIZATIONRESPONSE,
  '__module__' : 'protopia.api.tenant.v1beta1.organization_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.tenant.v1beta1.DeleteOrganizationResponse)
  })
_sym_db.RegisterMessage(DeleteOrganizationResponse)

AddOrganizationMembersRequest = _reflection.GeneratedProtocolMessageType('AddOrganizationMembersRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDORGANIZATIONMEMBERSREQUEST,
  '__module__' : 'protopia.api.tenant.v1beta1.organization_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.tenant.v1beta1.AddOrganizationMembersRequest)
  })
_sym_db.RegisterMessage(AddOrganizationMembersRequest)

AddOrganizationMembersResponse = _reflection.GeneratedProtocolMessageType('AddOrganizationMembersResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDORGANIZATIONMEMBERSRESPONSE,
  '__module__' : 'protopia.api.tenant.v1beta1.organization_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.tenant.v1beta1.AddOrganizationMembersResponse)
  })
_sym_db.RegisterMessage(AddOrganizationMembersResponse)

RemoveOrganizationMemberRequest = _reflection.GeneratedProtocolMessageType('RemoveOrganizationMemberRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEORGANIZATIONMEMBERREQUEST,
  '__module__' : 'protopia.api.tenant.v1beta1.organization_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.tenant.v1beta1.RemoveOrganizationMemberRequest)
  })
_sym_db.RegisterMessage(RemoveOrganizationMemberRequest)

RemoveOrganizationMemberResponse = _reflection.GeneratedProtocolMessageType('RemoveOrganizationMemberResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEORGANIZATIONMEMBERRESPONSE,
  '__module__' : 'protopia.api.tenant.v1beta1.organization_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.tenant.v1beta1.RemoveOrganizationMemberResponse)
  })
_sym_db.RegisterMessage(RemoveOrganizationMemberResponse)


DESCRIPTOR._options = None

_ORGANIZATIONSERVICE = _descriptor.ServiceDescriptor(
  name='OrganizationService',
  full_name='protopia.cloud.tenant.v1beta1.OrganizationService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=867,
  serialized_end=1846,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateOrganization',
    full_name='protopia.cloud.tenant.v1beta1.OrganizationService.CreateOrganization',
    index=0,
    containing_service=None,
    input_type=_ORGANIZATION,
    output_type=_ORGANIZATION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetOrganization',
    full_name='protopia.cloud.tenant.v1beta1.OrganizationService.GetOrganization',
    index=1,
    containing_service=None,
    input_type=_GETORGANIZATIONREQUEST,
    output_type=_ORGANIZATION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOrganizations',
    full_name='protopia.cloud.tenant.v1beta1.OrganizationService.ListOrganizations',
    index=2,
    containing_service=None,
    input_type=_LISTORGANIZATIONSREQUEST,
    output_type=_LISTORGANIZATIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateOrganization',
    full_name='protopia.cloud.tenant.v1beta1.OrganizationService.UpdateOrganization',
    index=3,
    containing_service=None,
    input_type=_UPDATEORGANIZATIONREQUEST,
    output_type=_UPDATEORGANIZATIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteOrganization',
    full_name='protopia.cloud.tenant.v1beta1.OrganizationService.DeleteOrganization',
    index=4,
    containing_service=None,
    input_type=_DELETEORGANIZATIONREQUEST,
    output_type=_DELETEORGANIZATIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddOrganizationMembers',
    full_name='protopia.cloud.tenant.v1beta1.OrganizationService.AddOrganizationMembers',
    index=5,
    containing_service=None,
    input_type=_ADDORGANIZATIONMEMBERSREQUEST,
    output_type=_ADDORGANIZATIONMEMBERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveOrganizationMember',
    full_name='protopia.cloud.tenant.v1beta1.OrganizationService.RemoveOrganizationMember',
    index=6,
    containing_service=None,
    input_type=_REMOVEORGANIZATIONMEMBERREQUEST,
    output_type=_REMOVEORGANIZATIONMEMBERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ORGANIZATIONSERVICE)

DESCRIPTOR.services_by_name['OrganizationService'] = _ORGANIZATIONSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from protopia.api.data.v1beta1 import data_source_pb2 as protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2


class DataSourceServiceStub(object):
    """DataSource service manages the CRUD operations on a data source.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateDatasource = channel.unary_unary(
                '/protopia.cloud.governance.v1beta1.DataSourceService/CreateDatasource',
                request_serializer=protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.DataSource.SerializeToString,
                response_deserializer=protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.DataSource.FromString,
                )
        self.ListDataSources = channel.unary_unary(
                '/protopia.cloud.governance.v1beta1.DataSourceService/ListDataSources',
                request_serializer=protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.ListDataSourcesRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.ListDataSourcesResponse.FromString,
                )
        self.GetDataSource = channel.unary_unary(
                '/protopia.cloud.governance.v1beta1.DataSourceService/GetDataSource',
                request_serializer=protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.GetDataSourceRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.DataSource.FromString,
                )
        self.UpdateDatasource = channel.unary_unary(
                '/protopia.cloud.governance.v1beta1.DataSourceService/UpdateDatasource',
                request_serializer=protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.UpdateDataSourceRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.DataSource.FromString,
                )
        self.DeleteDatasource = channel.unary_unary(
                '/protopia.cloud.governance.v1beta1.DataSourceService/DeleteDatasource',
                request_serializer=protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.DeleteDataSourceRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.DeleteDataSourceResponse.FromString,
                )


class DataSourceServiceServicer(object):
    """DataSource service manages the CRUD operations on a data source.
    """

    def CreateDatasource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDataSources(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataSource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDatasource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDatasource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataSourceServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateDatasource': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDatasource,
                    request_deserializer=protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.DataSource.FromString,
                    response_serializer=protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.DataSource.SerializeToString,
            ),
            'ListDataSources': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDataSources,
                    request_deserializer=protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.ListDataSourcesRequest.FromString,
                    response_serializer=protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.ListDataSourcesResponse.SerializeToString,
            ),
            'GetDataSource': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataSource,
                    request_deserializer=protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.GetDataSourceRequest.FromString,
                    response_serializer=protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.DataSource.SerializeToString,
            ),
            'UpdateDatasource': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDatasource,
                    request_deserializer=protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.UpdateDataSourceRequest.FromString,
                    response_serializer=protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.DataSource.SerializeToString,
            ),
            'DeleteDatasource': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDatasource,
                    request_deserializer=protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.DeleteDataSourceRequest.FromString,
                    response_serializer=protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.DeleteDataSourceResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'protopia.cloud.governance.v1beta1.DataSourceService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataSourceService(object):
    """DataSource service manages the CRUD operations on a data source.
    """

    @staticmethod
    def CreateDatasource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.governance.v1beta1.DataSourceService/CreateDatasource',
            protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.DataSource.SerializeToString,
            protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.DataSource.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDataSources(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.governance.v1beta1.DataSourceService/ListDataSources',
            protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.ListDataSourcesRequest.SerializeToString,
            protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.ListDataSourcesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataSource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.governance.v1beta1.DataSourceService/GetDataSource',
            protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.GetDataSourceRequest.SerializeToString,
            protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.DataSource.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDatasource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.governance.v1beta1.DataSourceService/UpdateDatasource',
            protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.UpdateDataSourceRequest.SerializeToString,
            protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.DataSource.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDatasource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.governance.v1beta1.DataSourceService/DeleteDatasource',
            protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.DeleteDataSourceRequest.SerializeToString,
            protopia_dot_api_dot_data_dot_v1beta1_dot_data__source__pb2.DeleteDataSourceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from protopia.api.iam.v1beta1 import iam_role_pb2 as protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2
from protopia.api.iam.v1beta1 import role_pb2 as protopia_dot_api_dot_iam_dot_v1beta1_dot_role__pb2


class IAMRoleStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.UpsertRole = channel.unary_unary(
                '/protopia.cloud.iam.v1beta1.IAMRole/UpsertRole',
                request_serializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_role__pb2.Role.SerializeToString,
                response_deserializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_role__pb2.Role.FromString,
                )
        self.GetRole = channel.unary_unary(
                '/protopia.cloud.iam.v1beta1.IAMRole/GetRole',
                request_serializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.GetRoleRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_role__pb2.Role.FromString,
                )
        self.DeleteRole = channel.unary_unary(
                '/protopia.cloud.iam.v1beta1.IAMRole/DeleteRole',
                request_serializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.DeleteRoleRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.DeleteRoleResponse.FromString,
                )
        self.ListRoles = channel.unary_unary(
                '/protopia.cloud.iam.v1beta1.IAMRole/ListRoles',
                request_serializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.ListRolesRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.ListRolesResponse.FromString,
                )
        self.AddRoleMembers = channel.unary_unary(
                '/protopia.cloud.iam.v1beta1.IAMRole/AddRoleMembers',
                request_serializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.AddRoleMembersRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.AddRoleMembersResponse.FromString,
                )
        self.RemoveRoleMember = channel.unary_unary(
                '/protopia.cloud.iam.v1beta1.IAMRole/RemoveRoleMember',
                request_serializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.RemoveRoleMemberRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.RemoveRoleMemberResponse.FromString,
                )


class IAMRoleServicer(object):
    """Missing associated documentation comment in .proto file."""

    def UpsertRole(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRole(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteRole(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRoles(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddRoleMembers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveRoleMember(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_IAMRoleServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'UpsertRole': grpc.unary_unary_rpc_method_handler(
                    servicer.UpsertRole,
                    request_deserializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_role__pb2.Role.FromString,
                    response_serializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_role__pb2.Role.SerializeToString,
            ),
            'GetRole': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRole,
                    request_deserializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.GetRoleRequest.FromString,
                    response_serializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_role__pb2.Role.SerializeToString,
            ),
            'DeleteRole': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteRole,
                    request_deserializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.DeleteRoleRequest.FromString,
                    response_serializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.DeleteRoleResponse.SerializeToString,
            ),
            'ListRoles': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRoles,
                    request_deserializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.ListRolesRequest.FromString,
                    response_serializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.ListRolesResponse.SerializeToString,
            ),
            'AddRoleMembers': grpc.unary_unary_rpc_method_handler(
                    servicer.AddRoleMembers,
                    request_deserializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.AddRoleMembersRequest.FromString,
                    response_serializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.AddRoleMembersResponse.SerializeToString,
            ),
            'RemoveRoleMember': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveRoleMember,
                    request_deserializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.RemoveRoleMemberRequest.FromString,
                    response_serializer=protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.RemoveRoleMemberResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'protopia.cloud.iam.v1beta1.IAMRole', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class IAMRole(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def UpsertRole(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.iam.v1beta1.IAMRole/UpsertRole',
            protopia_dot_api_dot_iam_dot_v1beta1_dot_role__pb2.Role.SerializeToString,
            protopia_dot_api_dot_iam_dot_v1beta1_dot_role__pb2.Role.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRole(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.iam.v1beta1.IAMRole/GetRole',
            protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.GetRoleRequest.SerializeToString,
            protopia_dot_api_dot_iam_dot_v1beta1_dot_role__pb2.Role.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteRole(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.iam.v1beta1.IAMRole/DeleteRole',
            protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.DeleteRoleRequest.SerializeToString,
            protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.DeleteRoleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListRoles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.iam.v1beta1.IAMRole/ListRoles',
            protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.ListRolesRequest.SerializeToString,
            protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.ListRolesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddRoleMembers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.iam.v1beta1.IAMRole/AddRoleMembers',
            protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.AddRoleMembersRequest.SerializeToString,
            protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.AddRoleMembersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveRoleMember(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.iam.v1beta1.IAMRole/RemoveRoleMember',
            protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.RemoveRoleMemberRequest.SerializeToString,
            protopia_dot_api_dot_iam_dot_v1beta1_dot_iam__role__pb2.RemoveRoleMemberResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from protopia.api.tenant.v1beta1 import organization_pb2 as protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2


class OrganizationServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateOrganization = channel.unary_unary(
                '/protopia.cloud.tenant.v1beta1.OrganizationService/CreateOrganization',
                request_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.Organization.SerializeToString,
                response_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.Organization.FromString,
                )
        self.GetOrganization = channel.unary_unary(
                '/protopia.cloud.tenant.v1beta1.OrganizationService/GetOrganization',
                request_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.GetOrganizationRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.Organization.FromString,
                )
        self.ListOrganizations = channel.unary_unary(
                '/protopia.cloud.tenant.v1beta1.OrganizationService/ListOrganizations',
                request_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.ListOrganizationsRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.ListOrganizationsResponse.FromString,
                )
        self.UpdateOrganization = channel.unary_unary(
                '/protopia.cloud.tenant.v1beta1.OrganizationService/UpdateOrganization',
                request_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.UpdateOrganizationRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.UpdateOrganizationResponse.FromString,
                )
        self.DeleteOrganization = channel.unary_unary(
                '/protopia.cloud.tenant.v1beta1.OrganizationService/DeleteOrganization',
                request_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.DeleteOrganizationRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.DeleteOrganizationResponse.FromString,
                )
        self.AddOrganizationMembers = channel.unary_unary(
                '/protopia.cloud.tenant.v1beta1.OrganizationService/AddOrganizationMembers',
                request_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.AddOrganizationMembersRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.AddOrganizationMembersResponse.FromString,
                )
        self.RemoveOrganizationMember = channel.unary_unary(
                '/protopia.cloud.tenant.v1beta1.OrganizationService/RemoveOrganizationMember',
                request_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.RemoveOrganizationMemberRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.RemoveOrganizationMemberResponse.FromString,
                )


class OrganizationServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateOrganization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrganizations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateOrganization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOrganization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddOrganizationMembers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveOrganizationMember(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OrganizationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrganization,
                    request_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.Organization.FromString,
                    response_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.Organization.SerializeToString,
            ),
            'GetOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganization,
                    request_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.GetOrganizationRequest.FromString,
                    response_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.Organization.SerializeToString,
            ),
            'ListOrganizations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrganizations,
                    request_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.ListOrganizationsRequest.FromString,
                    response_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.ListOrganizationsResponse.SerializeToString,
            ),
            'UpdateOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateOrganization,
                    request_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.UpdateOrganizationRequest.FromString,
                    response_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.UpdateOrganizationResponse.SerializeToString,
            ),
            'DeleteOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOrganization,
                    request_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.DeleteOrganizationRequest.FromString,
                    response_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.DeleteOrganizationResponse.SerializeToString,
            ),
            'AddOrganizationMembers': grpc.unary_unary_rpc_method_handler(
                    servicer.AddOrganizationMembers,
                    request_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.AddOrganizationMembersRequest.FromString,
                    response_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.AddOrganizationMembersResponse.SerializeToString,
            ),
            'RemoveOrganizationMember': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveOrganizationMember,
                    request_deserializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.RemoveOrganizationMemberRequest.FromString,
                    response_serializer=protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.RemoveOrganizationMemberResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'protopia.cloud.tenant.v1beta1.OrganizationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class OrganizationService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.tenant.v1beta1.OrganizationService/CreateOrganization',
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.Organization.SerializeToString,
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.Organization.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.tenant.v1beta1.OrganizationService/GetOrganization',
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.GetOrganizationRequest.SerializeToString,
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.Organization.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrganizations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.tenant.v1beta1.OrganizationService/ListOrganizations',
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.ListOrganizationsRequest.SerializeToString,
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.ListOrganizationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.tenant.v1beta1.OrganizationService/UpdateOrganization',
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.UpdateOrganizationRequest.SerializeToString,
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.UpdateOrganizationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.tenant.v1beta1.OrganizationService/DeleteOrganization',
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.DeleteOrganizationRequest.SerializeToString,
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.DeleteOrganizationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddOrganizationMembers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.tenant.v1beta1.OrganizationService/AddOrganizationMembers',
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.AddOrganizationMembersRequest.SerializeToString,
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.AddOrganizationMembersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveOrganizationMember(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.tenant.v1beta1.OrganizationService/RemoveOrganizationMember',
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.RemoveOrganizationMemberRequest.SerializeToString,
            protopia_dot_api_dot_tenant_dot_v1beta1_dot_organization__pb2.RemoveOrganizationMemberResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protopia/api/noise/v1beta1/internal/store.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protopia.api.noise.v1beta1 import distribution_pb2 as protopia_dot_api_dot_noise_dot_v1beta1_dot_distribution__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protopia/api/noise/v1beta1/internal/store.proto',
  package='',
  syntax='proto3',
  serialized_options=b'ZJgithub.com/protopia-ai/cloud/internal/pkg/api/noise/v1beta1;noise_internal',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/protopia/api/noise/v1beta1/internal/store.proto\x1a-protopia/api/noise/v1beta1/distribution.proto\"\x80\x01\n\x1dStoreNoiseDistributionRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\x04\x12N\n\x0c\x64istribution\x18\x02 \x01(\x0b\x32\x38.protopia.cloud.noise.v1beta1.EncryptedNoiseDistribution\" \n\x1eStoreNoiseDistributionResponse\"A\n RetrieveNoiseDistributionRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\x04\x12\x0c\n\x04nnid\x18\x02 \x01(\t2\xdc\x01\n\x05Store\x12Y\n\x16StoreNoiseDistribution\x12\x1e.StoreNoiseDistributionRequest\x1a\x1f.StoreNoiseDistributionResponse\x12x\n\x19RetrieveNoiseDistribution\x12!.RetrieveNoiseDistributionRequest\x1a\x38.protopia.cloud.noise.v1beta1.EncryptedNoiseDistributionBLZJgithub.com/protopia-ai/cloud/internal/pkg/api/noise/v1beta1;noise_internalb\x06proto3'
  ,
  dependencies=[protopia_dot_api_dot_noise_dot_v1beta1_dot_distribution__pb2.DESCRIPTOR,])




_STORENOISEDISTRIBUTIONREQUEST = _descriptor.Descriptor(
  name='StoreNoiseDistributionRequest',
  full_name='StoreNoiseDistributionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='StoreNoiseDistributionRequest.user_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distribution', full_name='StoreNoiseDistributionRequest.distribution', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=99,
  serialized_end=227,
)


_STORENOISEDISTRIBUTIONRESPONSE = _descriptor.Descriptor(
  name='StoreNoiseDistributionResponse',
  full_name='StoreNoiseDistributionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=229,
  serialized_end=261,
)


_RETRIEVENOISEDISTRIBUTIONREQUEST = _descriptor.Descriptor(
  name='RetrieveNoiseDistributionRequest',
  full_name='RetrieveNoiseDistributionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='RetrieveNoiseDistributionRequest.user_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nnid', full_name='RetrieveNoiseDistributionRequest.nnid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=328,
)

_STORENOISEDISTRIBUTIONREQUEST.fields_by_name['distribution'].message_type = protopia_dot_api_dot_noise_dot_v1beta1_dot_distribution__pb2._ENCRYPTEDNOISEDISTRIBUTION
DESCRIPTOR.message_types_by_name['StoreNoiseDistributionRequest'] = _STORENOISEDISTRIBUTIONREQUEST
DESCRIPTOR.message_types_by_name['StoreNoiseDistributionResponse'] = _STORENOISEDISTRIBUTIONRESPONSE
DESCRIPTOR.message_types_by_name['RetrieveNoiseDistributionRequest'] = _RETRIEVENOISEDISTRIBUTIONREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StoreNoiseDistributionRequest = _reflection.GeneratedProtocolMessageType('StoreNoiseDistributionRequest', (_message.Message,), {
  'DESCRIPTOR' : _STORENOISEDISTRIBUTIONREQUEST,
  '__module__' : 'protopia.api.noise.v1beta1.internal.store_pb2'
  # @@protoc_insertion_point(class_scope:StoreNoiseDistributionRequest)
  })
_sym_db.RegisterMessage(StoreNoiseDistributionRequest)

StoreNoiseDistributionResponse = _reflection.GeneratedProtocolMessageType('StoreNoiseDistributionResponse', (_message.Message,), {
  'DESCRIPTOR' : _STORENOISEDISTRIBUTIONRESPONSE,
  '__module__' : 'protopia.api.noise.v1beta1.internal.store_pb2'
  # @@protoc_insertion_point(class_scope:StoreNoiseDistributionResponse)
  })
_sym_db.RegisterMessage(StoreNoiseDistributionResponse)

RetrieveNoiseDistributionRequest = _reflection.GeneratedProtocolMessageType('RetrieveNoiseDistributionRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVENOISEDISTRIBUTIONREQUEST,
  '__module__' : 'protopia.api.noise.v1beta1.internal.store_pb2'
  # @@protoc_insertion_point(class_scope:RetrieveNoiseDistributionRequest)
  })
_sym_db.RegisterMessage(RetrieveNoiseDistributionRequest)


DESCRIPTOR._options = None

_STORE = _descriptor.ServiceDescriptor(
  name='Store',
  full_name='Store',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=331,
  serialized_end=551,
  methods=[
  _descriptor.MethodDescriptor(
    name='StoreNoiseDistribution',
    full_name='Store.StoreNoiseDistribution',
    index=0,
    containing_service=None,
    input_type=_STORENOISEDISTRIBUTIONREQUEST,
    output_type=_STORENOISEDISTRIBUTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RetrieveNoiseDistribution',
    full_name='Store.RetrieveNoiseDistribution',
    index=1,
    containing_service=None,
    input_type=_RETRIEVENOISEDISTRIBUTIONREQUEST,
    output_type=protopia_dot_api_dot_noise_dot_v1beta1_dot_distribution__pb2._ENCRYPTEDNOISEDISTRIBUTION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STORE)

DESCRIPTOR.services_by_name['Store'] = _STORE

# @@protoc_insertion_point(module_scope)
